<!-- DO NOT EDIT: this file is automatically generated using scw-doc-gen -->
# Documentation for `scw redis`
Managed Database for Redis™ API
  
- [Access Control List (ACL) management commands](#access-control-list-(acl)-management-commands)
  - [Add ACL rules for a given cluster](#add-acl-rules-for-a-given-cluster)
  - [Delete an ACL rule for a given cluster](#delete-an-acl-rule-for-a-given-cluster)
  - [Get an ACL rule](#get-an-acl-rule)
  - [Set ACL rules for a given cluster](#set-acl-rules-for-a-given-cluster)
- [Cluster management commands](#cluster-management-commands)
  - [Create a cluster](#create-a-cluster)
  - [Delete a cluster](#delete-a-cluster)
  - [Get a cluster](#get-a-cluster)
  - [Get the TLS certificate of a cluster](#get-the-tls-certificate-of-a-cluster)
  - [List clusters](#list-clusters)
  - [Get metrics of a cluster](#get-metrics-of-a-cluster)
  - [Migrate a cluster](#migrate-a-cluster)
  - [Renew the TLS certificate of a cluster](#renew-the-tls-certificate-of-a-cluster)
  - [Update a cluster](#update-a-cluster)
- [Endpoints management commands](#endpoints-management-commands)
  - [Add endpoints for a given cluster](#add-endpoints-for-a-given-cluster)
  - [Delete an endpoint for a given cluster](#delete-an-endpoint-for-a-given-cluster)
  - [Get an endpoint](#get-an-endpoint)
  - [Set endpoints for a given cluster](#set-endpoints-for-a-given-cluster)
- [Node Types management commands](#node-types-management-commands)
  - [List available node types](#list-available-node-types)
- [Settings management commands](#settings-management-commands)
  - [Add cluster settings](#add-cluster-settings)
  - [Delete a cluster setting](#delete-a-cluster-setting)
  - [Set cluster settings](#set-cluster-settings)
- [Redis™ version management commands](#redis™-version-management-commands)
  - [List available Redis™ versions](#list-available-redis™-versions)

  
## Access Control List (ACL) management commands

Network Access Control List allows to control network inbound traffic allowed by setting up ACL rules. ACL rules could be created, edited, deleted.



### Add ACL rules for a given cluster

Add ACL rules for a given cluster.

**Usage:**

```
scw redis acl add [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| cluster-id | Required | UUID of the cluster you want to add acl rules to |
| acl-rules.{index}.ip |  | IPv4 network address of the rule |
| acl-rules.{index}.description |  | Description of the rule |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Delete an ACL rule for a given cluster

Delete an ACL rule for a given cluster.

**Usage:**

```
scw redis acl delete [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| acl-id | Required | UUID of the acl rule you want to delete |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Get an ACL rule

Get an ACL rule.

**Usage:**

```
scw redis acl get <acl-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| acl-id | Required | UUID of the acl rule you want to get |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Set ACL rules for a given cluster

Set ACL rules for a given cluster.

**Usage:**

```
scw redis acl set [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| cluster-id | Required | UUID of the cluster where the ACL rules has to be set |
| acl-rules.{index}.ip |  | IPv4 network address of the rule |
| acl-rules.{index}.description |  | Description of the rule |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



## Cluster management commands

A Managed Database for Redis™ cluster is composed of one or more Nodes depending of the cluster_size setting.



### Create a cluster

Create a cluster.

**Usage:**

```
scw redis cluster create [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| project-id |  | Project ID to use. If none is passed the default project ID will be used |
| name | Default: `<generated>` | Name of the cluster |
| version | Required | Redis™ engine version of the cluster |
| tags.{index} |  | Tags to apply to the cluster |
| node-type | Required | Type of node to use for the cluster |
| user-name | Required | Name of the user created when the cluster is created |
| password | Required | Password of the user |
| cluster-size |  | Number of nodes for the cluster |
| acl-rules.{index}.ip |  | IPv4 network address of the rule |
| acl-rules.{index}.description |  | Description of the rule |
| endpoints.{index}.private-network.id |  | UUID of the private network to be connected to the cluster |
| endpoints.{index}.private-network.service-ips.{index} |  | Endpoint IPv4 adress with a CIDR notation. You must provide at least one IPv4 per node. Check documentation about IP and subnet limitation. |
| tls-enabled |  | Whether or not TLS is enabled |
| cluster-settings.{index}.value |  | Value of the setting |
| cluster-settings.{index}.name |  | Name of the setting |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Delete a cluster

Delete a cluster.

**Usage:**

```
scw redis cluster delete <cluster-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| cluster-id | Required | UUID of the cluster to delete |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Get a cluster

Get a cluster.

**Usage:**

```
scw redis cluster get <cluster-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| cluster-id | Required | UUID of the cluster |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Get the TLS certificate of a cluster

Get the TLS certificate of a cluster.

**Usage:**

```
scw redis cluster get-certificate <cluster-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| cluster-id | Required | UUID of the cluster |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### List clusters

List clusters.

**Usage:**

```
scw redis cluster list [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| tags.{index} |  | Tags of the clusters to filter upon |
| name |  | Name of the clusters to filter upon |
| order-by | One of: `created_at_asc`, `created_at_desc`, `name_asc`, `name_desc` | Criteria to use when ordering cluster listing |
| project-id |  | Project ID to list the cluster of |
| organization-id |  | Organization ID to list the cluster of |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Get metrics of a cluster

Get metrics of a cluster.

**Usage:**

```
scw redis cluster metrics <cluster-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| cluster-id | Required | UUID of the cluster |
| start-date |  | Start date to gather metrics from |
| end-date |  | End date to gather metrics from |
| metric-name |  | Name of the metric to gather |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Migrate a cluster

Migrate a cluster.

**Usage:**

```
scw redis cluster migrate <cluster-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| version |  | Redis™ engine version of the cluster |
| node-type |  | Type of node to use for the cluster |
| cluster-size |  | Number of nodes for the cluster |
| cluster-id | Required | UUID of the cluster to update |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Renew the TLS certificate of a cluster

Renew the TLS certificate of a cluster.

**Usage:**

```
scw redis cluster renew-certificate <cluster-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| cluster-id | Required | UUID of the cluster |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Update a cluster

Update a cluster.

**Usage:**

```
scw redis cluster update <cluster-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| name |  | Name of the cluster |
| tags.{index} |  | Tags of a given cluster |
| user-name |  | Name of the cluster user |
| password |  | Password of the cluster user |
| cluster-id | Required | UUID of the cluster to update |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



## Endpoints management commands

Manage endpoints to access to your cluster trough Public or Private networks



### Add endpoints for a given cluster

Add endpoints for a given cluster.

**Usage:**

```
scw redis endpoint add [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| cluster-id | Required | UUID of the cluster you want to add endpoints to |
| endpoints.{index}.private-network.id |  | UUID of the private network to be connected to the cluster |
| endpoints.{index}.private-network.service-ips.{index} |  | Endpoint IPv4 adress with a CIDR notation. You must provide at least one IPv4 per node. Check documentation about IP and subnet limitation. |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Delete an endpoint for a given cluster

Delete an endpoint for a given cluster.

**Usage:**

```
scw redis endpoint delete [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| endpoint-id | Required | UUID of the endpoint you want to delete |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Get an endpoint

Get an endpoint.

**Usage:**

```
scw redis endpoint get <endpoint-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| endpoint-id | Required | UUID of the endpoint you want to get |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Set endpoints for a given cluster

Set endpoints for a given cluster.

**Usage:**

```
scw redis endpoint set [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| cluster-id | Required | UUID of the cluster where the endpoints has to be set |
| endpoints.{index}.private-network.id |  | UUID of the private network to be connected to the cluster |
| endpoints.{index}.private-network.service-ips.{index} |  | Endpoint IPv4 adress with a CIDR notation. You must provide at least one IPv4 per node. Check documentation about IP and subnet limitation. |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



## Node Types management commands

Node types powering your cluster.



### List available node types

List available node types.

**Usage:**

```
scw redis node-type list [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| include-disabled-types |  | Whether or not to include disabled types |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



## Settings management commands

Available Redis™ settings. Available settings depend on the Redis™ version.



### Add cluster settings

Add cluster settings.

**Usage:**

```
scw redis setting add [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| cluster-id | Required | UUID of the cluster you want to add settings to |
| settings.{index}.value |  | Value of the setting |
| settings.{index}.name |  | Name of the setting |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Delete a cluster setting

Delete a cluster setting.

**Usage:**

```
scw redis setting delete [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| cluster-id | Required | UUID of the cluster where the settings has to be set |
| settings-name |  | Setting name to delete |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



### Set cluster settings

Set cluster settings.

**Usage:**

```
scw redis setting set [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| cluster-id | Required | UUID of the cluster where the settings has to be set |
| settings.{index}.value |  | Value of the setting |
| settings.{index}.name |  | Name of the setting |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



## Redis™ version management commands

Redis™ versions powering your cluster.


### List available Redis™ versions

List available Redis™ versions.

**Usage:**

```
scw redis version list [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| include-disabled |  | Whether or not to include disabled Redis™ engine versions |
| include-beta |  | Whether or not to include beta Redis™ engine versions |
| include-deprecated |  | Whether or not to include deprecated Redis™ engine versions |
| version-name |  | List Redis™ engine versions that match a given name pattern |
| zone | Default: `fr-par-1`<br />One of: `fr-par-1`, `fr-par-2`, `nl-ams-1`, `pl-waw-1` | Zone to target. If none is passed will use default zone from the config |



